@@ -3,7 +3,7 @@
 	/**
 	 * Manage conversions in a database
 	 *
-	 * $Id: conversions.php,v 1.9 2004/09/01 16:35:58 jollytoad Exp $
+	 * $Id: conversions.php,v 1.15 2007/08/31 18:30:10 ioguix Exp $
 	 */
 
 	// Include application functions
@@ -11,42 +11,41 @@
 	
 	$action = (isset($_REQUEST['action'])) ? $_REQUEST['action'] : '';
 	if (!isset($msg)) $msg = '';
-	$PHP_SELF = $_SERVER['PHP_SELF'];
 
 	/**
 	 * Show default list of conversions in the database
 	 */
 	function doDefault($msg = '') {
 		global $data, $conf, $misc, $database;
-		global $PHP_SELF, $lang;
+		global $lang;
 
 		$misc->printTrail('schema');
 		$misc->printTabs('schema', 'conversions');
 		$misc->printMsg($msg);
 		
-		$conversions = &$data->getconversions();
+		$conversions = $data->getconversions();
 		
 		$columns = array(
 			'conversion' => array(
 				'title' => $lang['strname'],
-				'field' => 'conname',
+				'field' => field('conname'),
 			),
 			'source_encoding' => array(
 				'title' => $lang['strsourceencoding'],
-				'field' => 'conforencoding',
+				'field' => field('conforencoding'),
 			),
 			'target_encoding' => array(
 				'title' => $lang['strtargetencoding'],
-				'field' => 'contoencoding',
+				'field' => field('contoencoding'),
 			),
 			'default' => array(
 				'title' => $lang['strdefault'],
-				'field' => 'condefault',
+				'field' => field('condefault'),
 				'type'  => 'yesno',
 			),
 			'comment' => array(
 				'title' => $lang['strcomment'],
-				'field' => 'concomment',
+				'field' => field('concomment'),
 			),
 		);
 		
@@ -54,7 +53,27 @@
 		
 		$misc->printTable($conversions, $columns, $actions, $lang['strnoconversions']);
 	}
-
+	
+	/**
+	 * Generate XML for the browser tree.
+	 */
+	function doTree() {
+		global $misc, $data;
+		
+		$conversions = $data->getconversions();
+		
+		$attrs = array(
+			'text'   => field('conname'),
+			'icon'   => 'Conversion',
+			'toolTip'=> field('concomment')
+		);
+		
+		$misc->printTreeXML($conversions, $attrs);
+		exit;
+	}
+	
+	if ($action == 'tree') doTree();
+	
 	$misc->printHeader($lang['strconversions']);
 	$misc->printBody();
 
