@@ -3,7 +3,7 @@
 	/**
 	 * Manage domains in a database
 	 *
-	 * $Id: domains.php,v 1.13 2004/06/03 06:42:20 chriskl Exp $
+	 * $Id: domains.php,v 1.34 2007/09/13 13:41:01 ioguix Exp $
 	 */
 
 	// Include application functions
@@ -11,7 +11,6 @@
 	
 	$action = (isset($_REQUEST['action'])) ? $_REQUEST['action'] : '';
 	if (!isset($msg)) $msg = '';
-	$PHP_SELF = $_SERVER['PHP_SELF'];
 	
 	/** 
 	 * Function to save after altering a domain
@@ -32,41 +31,42 @@
 	 */
 	function doAlter($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 	
-		echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strdomains']}: ", $misc->printVal($_REQUEST['domain']), ": {$lang['stralter']}</h2>\n";
+		$misc->printTrail('domain');
+		$misc->printTitle($lang['stralter'],'pg.domain.alter');
 		$misc->printMsg($msg);
 		
 		// Fetch domain info
-		$domaindata = &$data->getDomain($_REQUEST['domain']);
+		$domaindata = $data->getDomain($_REQUEST['domain']);
 		// Fetch all users
-		$users = &$data->getUsers();
+		$users = $data->getUsers();
 		
 		if ($domaindata->recordCount() > 0) {
 			if (!isset($_POST['domname'])) {				
-				$_POST['domtype'] = $domaindata->f['domtype'];
-				$_POST['domdefault'] = $domaindata->f['domdef'];
-				$domaindata->f['domnotnull'] = $data->phpBool($domaindata->f['domnotnull']);
-				if ($domaindata->f['domnotnull']) $_POST['domnotnull'] = 'on';
-				$_POST['domowner'] = $domaindata->f['domowner'];
+				$_POST['domtype'] = $domaindata->fields['domtype'];
+				$_POST['domdefault'] = $domaindata->fields['domdef'];
+				$domaindata->fields['domnotnull'] = $data->phpBool($domaindata->fields['domnotnull']);
+				if ($domaindata->fields['domnotnull']) $_POST['domnotnull'] = 'on';
+				$_POST['domowner'] = $domaindata->fields['domowner'];
 			}
 			
 			// Display domain info
-			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+			echo "<form action=\"domains.php\" method=\"post\">\n";
 			echo "<table>\n";
-			echo "<tr><th class=\"data left required\" width=\"70\">{$lang['strname']}</th>\n";
-			echo "<td class=\"data1\">", $misc->printVal($domaindata->f['domname']), "</td></tr>\n";
+			echo "<tr><th class=\"data left required\" style=\"width: 70px\">{$lang['strname']}</th>\n";
+			echo "<td class=\"data1\">", $misc->printVal($domaindata->fields['domname']), "</td></tr>\n";
 			echo "<tr><th class=\"data left required\">{$lang['strtype']}</th>\n";
-			echo "<td class=\"data1\">", $misc->printVal($domaindata->f['domtype']), "</td></tr>\n";
-			echo "<tr><th class=\"data left\">{$lang['strnotnull']}</th>\n";
-			echo "<td class=\"data1\"><input type=\"checkbox\" name=\"domnotnull\"", (isset($_POST['domnotnull']) ? ' checked="checked"' : ''), " /></td></tr>\n";
+			echo "<td class=\"data1\">", $misc->printVal($domaindata->fields['domtype']), "</td></tr>\n";
+			echo "<tr><th class=\"data left\"><label for=\"domnotnull\">{$lang['strnotnull']}</label></th>\n";
+			echo "<td class=\"data1\"><input type=\"checkbox\" id=\"domnotnull\" name=\"domnotnull\"", (isset($_POST['domnotnull']) ? ' checked="checked"' : ''), " /></td></tr>\n";
 			echo "<tr><th class=\"data left\">{$lang['strdefault']}</th>\n";
-			echo "<td class=\"data1\"><input name=\"domdefault\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" value=\"", 
+			echo "<td class=\"data1\"><input name=\"domdefault\" size=\"32\" value=\"", 
 				htmlspecialchars($_POST['domdefault']), "\" /></td></tr>\n";
 			echo "<tr><th class=\"data left required\">{$lang['strowner']}</th>\n";
 			echo "<td class=\"data1\"><select name=\"domowner\">";
 			while (!$users->EOF) {
-				$uname = $users->f[$data->uFields['uname']];
+				$uname = $users->fields['usename'];
 				echo "<option value=\"", htmlspecialchars($uname), "\"",
 					($uname == $_POST['domowner']) ? ' selected="selected"' : '', ">", htmlspecialchars($uname), "</option>\n";
 				$users->moveNext();
@@ -87,18 +87,18 @@
 	 * Confirm and then actually add a CHECK constraint
 	 */
 	function addCheck($confirm, $msg = '') {
-		global $PHP_SELF, $data, $data, $misc;
+		global $data, $misc;
 		global $lang;
 
 		if (!isset($_POST['name'])) $_POST['name'] = '';
 		if (!isset($_POST['definition'])) $_POST['definition'] = '';
 
 		if ($confirm) {
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strdomains']}: ",
-				$misc->printVal($_REQUEST['domain']), ": {$lang['straddcheck']}</h2>\n";
+			$misc->printTrail('domain');
+			$misc->printTitle($lang['straddcheck'],'pg.constraint.check');
 			$misc->printMsg($msg);
 
-			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+			echo "<form action=\"domains.php\" method=\"post\">\n";
 			echo "<table>\n";
 			echo "<tr><th class=\"data\">{$lang['strname']}</th>\n";
 			echo "<th class=\"data required\">{$lang['strdefinition']}</th></tr>\n";
@@ -110,10 +110,10 @@
 				htmlspecialchars($_POST['definition']), "\" />)</td></tr>\n";
 			echo "</table>\n";
 
-			echo "<input type=\"hidden\" name=\"action\" value=\"save_add_check\" />\n";
+			echo "<p><input type=\"hidden\" name=\"action\" value=\"save_add_check\" />\n";
 			echo "<input type=\"hidden\" name=\"domain\" value=\"", htmlspecialchars($_REQUEST['domain']), "\" />\n";
 			echo $misc->form;
-			echo "<p><input type=\"submit\" name=\"add\" value=\"{$lang['stradd']}\" />\n";
+			echo "<input type=\"submit\" name=\"add\" value=\"{$lang['stradd']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
 			echo "</form>\n";
 
@@ -137,23 +137,23 @@
 	 */
 	function doDropConstraint($confirm, $msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 
-		if ($confirm) { 
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strdomains']}: ", 
-				$misc->printVal($_REQUEST['domain']), ": ", $misc->printVal($_REQUEST['constraint']), ": {$lang['strdrop']}</h2>\n";
+		if ($confirm) {
+			$misc->printTrail('domain');
+			$misc->printTitle($lang['strdrop'],'pg.constraint.drop');
 			$misc->printMsg($msg);
 			
 			echo "<p>", sprintf($lang['strconfdropconstraint'], $misc->printVal($_REQUEST['constraint']), 
 				$misc->printVal($_REQUEST['domain'])), "</p>\n";	
-			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+			echo "<form action=\"domains.php\" method=\"post\">\n";
 			echo "<input type=\"hidden\" name=\"action\" value=\"drop_con\" />\n";
 			echo "<input type=\"hidden\" name=\"domain\" value=\"", htmlspecialchars($_REQUEST['domain']), "\" />\n";
 			echo "<input type=\"hidden\" name=\"constraint\" value=\"", htmlspecialchars($_REQUEST['constraint']), "\" />\n";
 			echo $misc->form;
 			// Show cascade drop option if supportd
 			if ($data->hasDropBehavior()) {
-				echo "<p><input type=\"checkbox\" name=\"cascade\" /> {$lang['strcascade']}</p>\n";
+				echo "<p><input type=\"checkbox\" id=\"cascade\" name=\"cascade\" /> <label for=\"cascade\">{$lang['strcascade']}</label></p>\n";
 			}
 			echo "<input type=\"submit\" name=\"drop\" value=\"{$lang['strdrop']}\" />\n";
 			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
@@ -174,36 +174,37 @@
 	 */
 	function doProperties($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 	
-		echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strdomains']}: ", $misc->printVal($_REQUEST['domain']), ": {$lang['strproperties']}</h2>\n";
+		$misc->printTrail('domain');
+		$misc->printTitle($lang['strproperties'],'pg.domain');
 		$misc->printMsg($msg);
 		
-		$domaindata = &$data->getDomain($_REQUEST['domain']);
+		$domaindata = $data->getDomain($_REQUEST['domain']);
 		
 		if ($domaindata->recordCount() > 0) {
 			// Show comment if any
-			if ($domaindata->f['domcomment'] !== null)
-				echo "<p class=\"comment\">", $misc->printVal($domaindata->f['domcomment']), "</p>\n";
+			if ($domaindata->fields['domcomment'] !== null)
+				echo "<p class=\"comment\">", $misc->printVal($domaindata->fields['domcomment']), "</p>\n";
 
 			// Display domain info
-			$domaindata->f['domnotnull'] = $data->phpBool($domaindata->f['domnotnull']);
+			$domaindata->fields['domnotnull'] = $data->phpBool($domaindata->fields['domnotnull']);
 			echo "<table>\n";
-			echo "<tr><th class=\"data left\" width=\"70\">{$lang['strname']}</th>\n";
-			echo "<td class=\"data1\">", $misc->printVal($domaindata->f['domname']), "</td></tr>\n";
+			echo "<tr><th class=\"data left\" style=\"width: 70px\">{$lang['strname']}</th>\n";
+			echo "<td class=\"data1\">", $misc->printVal($domaindata->fields['domname']), "</td></tr>\n";
 			echo "<tr><th class=\"data left\">{$lang['strtype']}</th>\n";
-			echo "<td class=\"data1\">", $misc->printVal($domaindata->f['domtype']), "</td></tr>\n";
+			echo "<td class=\"data1\">", $misc->printVal($domaindata->fields['domtype']), "</td></tr>\n";
 			echo "<tr><th class=\"data left\">{$lang['strnotnull']}</th>\n";
-			echo "<td class=\"data1\">", ($domaindata->f['domnotnull'] ? 'NOT NULL' : ''), "</td></tr>\n";
+			echo "<td class=\"data1\">", ($domaindata->fields['domnotnull'] ? 'NOT NULL' : ''), "</td></tr>\n";
 			echo "<tr><th class=\"data left\">{$lang['strdefault']}</th>\n";
-			echo "<td class=\"data1\">", $misc->printVal($domaindata->f['domdef']), "</td></tr>\n";
+			echo "<td class=\"data1\">", $misc->printVal($domaindata->fields['domdef']), "</td></tr>\n";
 			echo "<tr><th class=\"data left\">{$lang['strowner']}</th>\n";
-			echo "<td class=\"data1\">", $misc->printVal($domaindata->f['domowner']), "</td></tr>\n";
+			echo "<td class=\"data1\">", $misc->printVal($domaindata->fields['domowner']), "</td></tr>\n";
 			echo "</table>\n";
 			
 			// Display domain constraints
 			if ($data->hasDomainConstraints()) {
-				$domaincons = &$data->getDomainConstraints($_REQUEST['domain']);
+				$domaincons = $data->getDomainConstraints($_REQUEST['domain']);
 				if ($domaincons->recordCount() > 0) {
 					echo "<h3>{$lang['strconstraints']}</h3>\n";
 					echo "<table>\n";
@@ -212,13 +213,13 @@
 					
 					while (!$domaincons->EOF) {
 						$id = (($i % 2 ) == 0 ? '1' : '2');
-						echo "<tr><td class=\"data{$id}\">", $misc->printVal($domaincons->f[$data->cnFields['conname']]), "</td>";
+						echo "<tr><td class=\"data{$id}\">", $misc->printVal($domaincons->fields['conname']), "</td>";
 						echo "<td class=\"data{$id}\">";
-						echo $misc->printVal($domaincons->f[$data->cnFields['consrc']]);
+						echo $misc->printVal($domaincons->fields['consrc']);
 						echo "</td>";
 						echo "<td class=\"opbutton{$id}\">";
-						echo "<a href=\"$PHP_SELF?action=confirm_drop_con&amp;{$misc->href}&amp;constraint=", urlencode($domaincons->f[$data->cnFields['conname']]),
-							"&amp;domain=", urlencode($_REQUEST['domain']), "&amp;type=", urlencode($domaincons->f['contype']), "\">{$lang['strdrop']}</td></tr>\n";
+						echo "<a href=\"domains.php?action=confirm_drop_con&amp;{$misc->href}&amp;constraint=", urlencode($domaincons->fields['conname']),
+							"&amp;domain=", urlencode($_REQUEST['domain']), "&amp;type=", urlencode($domaincons->fields['contype']), "\">{$lang['strdrop']}</a></td></tr>\n";
 		
 						$domaincons->moveNext();
 						$i++;
@@ -230,14 +231,14 @@
 		}
 		else echo "<p>{$lang['strnodata']}</p>\n";
 		
-		echo "<p><a class=\"navlink\" href=\"$PHP_SELF?{$misc->href}\">{$lang['strshowalldomains']}</a>\n";
+		echo "<ul class=\"navlink\">\n\t<li><a href=\"domains.php?{$misc->href}\">{$lang['strshowalldomains']}</a></li>\n";
 		if ($data->hasDomainConstraints()) {
-			echo "| <a class=\"navlink\" href=\"{$PHP_SELF}?action=add_check&amp;{$misc->href}&amp;domain=", urlencode($_REQUEST['domain']),
-				"\">{$lang['straddcheck']}</a>\n";
-			echo "| <a class=\"navlink\" href=\"$PHP_SELF?action=alter&amp;{$misc->href}&amp;domain=", 
-				urlencode($_REQUEST['domain']), "\">{$lang['stralter']}</a>\n";
+			echo "\t<li><a href=\"domains.php?action=add_check&amp;{$misc->href}&amp;domain=", urlencode($_REQUEST['domain']),
+				"\">{$lang['straddcheck']}</a></li>\n";
+			echo "\t<li><a href=\"domains.php?action=alter&amp;{$misc->href}&amp;domain=", 
+				urlencode($_REQUEST['domain']), "\">{$lang['stralter']}</a></li>\n";
 		}
-		echo "</p>\n";
+		echo "</ul>\n";
 	}
 	
 	/**
@@ -245,22 +246,23 @@
 	 */
 	function doDrop($confirm) {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 
-		if ($confirm) { 
-			echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strdomains']}: ", $misc->printVal($_REQUEST['domain']), ": {$lang['strdrop']}</h2>\n";
+		if ($confirm) {
+			$misc->printTrail('domain');
+			$misc->printTitle($lang['strdrop'],'pg.domain.drop');
 			
 			echo "<p>", sprintf($lang['strconfdropdomain'], $misc->printVal($_REQUEST['domain'])), "</p>\n";	
-			echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
-			echo "<input type=\"hidden\" name=\"action\" value=\"drop\" />\n";
-			echo "<input type=\"hidden\" name=\"domain\" value=\"", htmlspecialchars($_REQUEST['domain']), "\" />\n";
-			echo $misc->form;
+			echo "<form action=\"domains.php\" method=\"post\">\n";
 			// Show cascade drop option if supportd
 			if ($data->hasDropBehavior()) {
-				echo "<p><input type=\"checkbox\" name=\"cascade\" /> {$lang['strcascade']}</p>\n";
+				echo "<p><input type=\"checkbox\" id=\"cascade\" name=\"cascade\" /><label for=\"cascade\">{$lang['strcascade']}</label></p>\n";
 			}
+			echo "<p><input type=\"hidden\" name=\"action\" value=\"drop\" />\n";
+			echo "<input type=\"hidden\" name=\"domain\" value=\"", htmlspecialchars($_REQUEST['domain']), "\" />\n";
+			echo $misc->form;
 			echo "<input type=\"submit\" name=\"drop\" value=\"{$lang['strdrop']}\" />\n";
-			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" />\n";
+			echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
 			echo "</form>\n";
 		}
 		else {
@@ -278,7 +280,7 @@
 	 */
 	function doCreate($msg = '') {
 		global $data, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 		
 		if (!isset($_POST['domname'])) $_POST['domname'] = '';
 		if (!isset($_POST['domtype'])) $_POST['domtype'] = '';
@@ -287,14 +289,15 @@
 		if (!isset($_POST['domdefault'])) $_POST['domdefault'] = '';
 		if (!isset($_POST['domcheck'])) $_POST['domcheck'] = '';
 
-		$types = &$data->getTypes(true);
+		$types = $data->getTypes(true);
 		
-		echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strdomains']}: {$lang['strcreatedomain']}</h2>\n";
+		$misc->printTrail('schema');
+		$misc->printTitle($lang['strcreatedomain'],'pg.domain.create');
 		$misc->printMsg($msg);
 
-		echo "<form action=\"$PHP_SELF\" method=\"post\">\n";
+		echo "<form action=\"domains.php\" method=\"post\">\n";
 		echo "<table>\n";
-		echo "<tr><th class=\"data left required\" width=\"70\">{$lang['strname']}</th>\n";
+		echo "<tr><th class=\"data left required\" style=\"width: 70px\">{$lang['strname']}</th>\n";
 		echo "<td class=\"data1\"><input name=\"domname\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" value=\"", 
 			htmlspecialchars($_POST['domname']), "\" /></td></tr>\n";
 		echo "<tr><th class=\"data left required\">{$lang['strtype']}</th>\n";
@@ -302,9 +305,9 @@
 		// Output return type list		
 		echo "<select name=\"domtype\">\n";
 		while (!$types->EOF) {
-			echo "<option value=\"", htmlspecialchars($types->f[$data->typFields['typname']]), "\"", 
-				($types->f[$data->typFields['typname']] == $_POST['domtype']) ? ' selected="selected"' : '', ">",
-				$misc->printVal($types->f[$data->typFields['typname']]), "</option>\n";
+			echo "<option value=\"", htmlspecialchars($types->fields['typname']), "\"", 
+				($types->fields['typname'] == $_POST['domtype']) ? ' selected="selected"' : '', ">",
+				$misc->printVal($types->fields['typname']), "</option>\n";
 			$types->moveNext();
 		}
 		echo "</select>\n";
@@ -318,21 +321,21 @@
 		echo "<option value=\"[]\"", ($_POST['domarray'] == '[]') ? ' selected="selected"' : '', ">[ ]</option>\n";
 		echo "</select></td></tr>\n";
 
-		echo "<tr><th class=\"data left\">{$lang['strnotnull']}</th>\n";
-		echo "<td class=\"data1\"><input type=\"checkbox\" name=\"domnotnull\"", 
+		echo "<tr><th class=\"data left\"><label for=\"domnotnull\">{$lang['strnotnull']}</label></th>\n";
+		echo "<td class=\"data1\"><input type=\"checkbox\" id=\"domnotnull\" name=\"domnotnull\"", 
 			(isset($_POST['domnotnull']) ? ' checked="checked"' : ''), " /></td></tr>\n";
 		echo "<tr><th class=\"data left\">{$lang['strdefault']}</th>\n";
-		echo "<td class=\"data1\"><input name=\"domdefault\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" value=\"", 
+		echo "<td class=\"data1\"><input name=\"domdefault\" size=\"32\" value=\"", 
 			htmlspecialchars($_POST['domdefault']), "\" /></td></tr>\n";
 		if ($data->hasDomainConstraints()) {
 			echo "<tr><th class=\"data left\">{$lang['strconstraints']}</th>\n";
-			echo "<td class=\"data1\">CHECK (<input name=\"domcheck\" size=\"32\" maxlength=\"{$data->_maxNameLen}\" value=\"", 
+			echo "<td class=\"data1\">CHECK (<input name=\"domcheck\" size=\"32\" value=\"", 
 				htmlspecialchars($_POST['domcheck']), "\" />)</td></tr>\n";
 		}
 		echo "</table>\n";
-		echo "<input type=\"hidden\" name=\"action\" value=\"save_create\" />\n";
+		echo "<p><input type=\"hidden\" name=\"action\" value=\"save_create\" />\n";
 		echo $misc->form;
-		echo "<p><input type=\"submit\" value=\"{$lang['strcreate']}\" />\n";
+		echo "<input type=\"submit\" value=\"{$lang['strcreate']}\" />\n";
 		echo "<input type=\"submit\" name=\"cancel\" value=\"{$lang['strcancel']}\" /></p>\n";
 		echo "</form>\n";
 	}
@@ -362,49 +365,95 @@
 	 */
 	function doDefault($msg = '') {
 		global $data, $conf, $misc;
-		global $PHP_SELF, $lang;
+		global $lang;
 		
-		echo "<h2>", $misc->printVal($_REQUEST['database']), ": {$lang['strdomains']}</h2>\n";
+		$misc->printTrail('schema');
+		$misc->printTabs('schema','domains');
 		$misc->printMsg($msg);
 		
-		$domains = &$data->getDomains();
+		$domains = $data->getDomains();
 		
-		if ($domains->recordCount() > 0) {
-			echo "<table>\n";
-			echo "<tr><th class=\"data\">{$lang['strdomain']}</th><th class=\"data\">{$lang['strtype']}</th><th class=\"data\">{$lang['strnotnull']}</th>";
-			echo "<th class=\"data\">{$lang['strdefault']}</th><th class=\"data\">{$lang['strowner']}</th>";
-			echo "<th colspan=\"2\" class=\"data\">{$lang['stractions']}</th>";
-			if ($conf['show_comments']) echo "<th class=\"data\">{$lang['strcomment']}</th>";
-			echo "</tr>\n";
-			$i = 0;
-			while (!$domains->EOF) {
-				$domains->f['domnotnull'] = $data->phpBool($domains->f['domnotnull']);
-				$id = (($i % 2) == 0 ? '1' : '2');
-				echo "<tr><td class=\"data{$id}\">", $misc->printVal($domains->f['domname']), "</td>\n";
-				echo "<td class=\"data{$id}\">", $misc->printVal($domains->f['domtype']), "</td>\n";
-				echo "<td class=\"data{$id}\">", ($domains->f['domnotnull'] ? 'NOT NULL' : ''), "</td>\n";
-				echo "<td class=\"data{$id}\">", $misc->printVal($domains->f['domdef']), "</td>\n";
-				echo "<td class=\"data{$id}\">", $misc->printVal($domains->f['domowner']), "</td>\n";
-				echo "<td class=\"opbutton{$id}\"><a href=\"$PHP_SELF?action=properties&amp;{$misc->href}&amp;domain=", urlencode($domains->f['domname']), "\">{$lang['strproperties']}</a></td>\n"; 
-				echo "<td class=\"opbutton{$id}\"><a href=\"$PHP_SELF?action=confirm_drop&amp;{$misc->href}&amp;domain=", urlencode($domains->f['domname']), "\">{$lang['strdrop']}</a></td>\n";
-				// Trim long comments
-				if (strlen($domains->f['domcomment']) > $conf['max_chars']) {
-					$domains->f['domcomment'] = substr($domains->f['domcomment'], 0, $conf['max_chars'] - 1) . $lang['strellipsis'];
-				}
-				if ($conf['show_comments']) echo "<td class=\"data{$id}\">", $misc->printVal($domains->f['domcomment']), "</td>\n";
-				echo "</tr>\n";
-				$domains->moveNext();
-				$i++;
-			}
-			echo "</table>\n";
-		}
-		else {
-			echo "<p>{$lang['strnodomains']}</p>\n";
-		}
+		$columns = array(
+			'domain' => array(
+				'title' => $lang['strdomain'],
+				'field' => field('domname'),
+				'url' => "domains.php?action=properties&amp;{$misc->href}&amp;",
+				'vars'  => array('domain' => 'domname'),
+			),
+			'type' => array(
+				'title' => $lang['strtype'],
+				'field' => field('domtype'),
+			),
+			'notnull' => array(
+				'title' => $lang['strnotnull'],
+				'field' => field('domnotnull'),
+				'type'  => 'bool',
+				'params'=> array('true' => 'NOT NULL', 'false' => ''),
+			),
+			'default' => array(
+				'title' => $lang['strdefault'],
+				'field' => field('domdef'),
+			),
+			'owner' => array(
+				'title' => $lang['strowner'],
+				'field' => field('domowner'),
+			),
+			'actions' => array(
+				'title' => $lang['stractions'],
+			),
+			'comment' => array(
+				'title' => $lang['strcomment'],
+				'field' => field('domcomment'),
+			),
+		);
 		
-		echo "<p><a class=\"navlink\" href=\"$PHP_SELF?action=create&amp;{$misc->href}\">{$lang['strcreatedomain']}</a></p>\n";
+		$actions = array(
+			'alter' => array(
+				'title'	=> $lang['stralter'],
+				'url'	=> "domains.php?action=alter&amp;{$misc->href}&amp;",
+				'vars'	=> array('domain' => 'domname'),
+			),
+			'drop' => array(
+				'title'	=> $lang['strdrop'],
+				'url'	=> "domains.php?action=confirm_drop&amp;{$misc->href}&amp;",
+				'vars'	=> array('domain' => 'domname'),
+			),
+		);
+		
+		$misc->printTable($domains, $columns, $actions, $lang['strnodomains']);
+		
+		echo "<p><a class=\"navlink\" href=\"domains.php?action=create&amp;{$misc->href}\">{$lang['strcreatedomain']}</a></p>\n";
 
 	}
+	
+	/**
+	 * Generate XML for the browser tree.
+	 */
+	function doTree() {
+		global $misc, $data;
+		
+		$domains = $data->getDomains();
+		
+		$reqvars = $misc->getRequestVars('domain');
+		
+		$attrs = array(
+			'text'   => field('domname'),
+			'icon'   => 'Domain',
+			'toolTip'=> field('domcomment'),
+			'action' => url('domains.php',
+							$reqvars,
+							array(
+								'action' => 'properties',
+								'domain' => field('domname')
+							)
+						)
+		);
+		
+		$misc->printTreeXML($domains, $attrs);
+		exit;
+	}
+	
+	if ($action == 'tree') doTree();
 
 	$misc->printHeader($lang['strdomains']);
 	$misc->printBody();
