@@ -10,8 +10,9 @@
 	$lang['applang'] = 'Česky';
 	$lang['appcharset'] = 'utf8';
 	$lang['applocale'] = 'cs_CZ';
-
 	$lang['appdbencoding'] = 'UNICODE';
+	$lang['applangdir'] = 'ltr';
+
 	// Basic strings
 	$lang['strintro'] = 'Vítejte v phpPgAdminu.';
 	$lang['strlogin'] = 'Přihlášení';
@@ -84,8 +85,8 @@
 	$lang['strimport'] = 'Import';
 	$lang['stradmin'] = 'Admin';
 	$lang['strvacuum'] = 'Vacuum';
-	$lang['stranalyze'] = 'Analyzovtť';
-	$lang['strcluster'] = 'Cluster';
+	$lang['stranalyze'] = 'Analyzovat';
+	$lang['strclusterindex'] = 'Cluster';
 	$lang['strreindex'] = 'Reindex';
 	$lang['strrun'] = 'Spustit';
 	$lang['strclustered'] = 'Clustered?';
@@ -121,7 +122,6 @@
 	$lang['streditsql'] = 'Uprav SQL';
 	$lang['strpaginate'] = 'Stránkování výsledků';
 	$lang['strstarttime'] = 'Počáteční čas';
-	$lang['strnoframes'] = 'Tato aplikace vyžaduje prohlížec s podporou framů.';
 	$lang['strbadconfig'] = 'Your config.inc.php is out of date. You will need to regenerate it from the new config.inc.php-dist.';
 	$lang['strnotloaded'] = 'PHP není zakompilováno s podporou PostgreSQL';
 	$lang['strbadschema'] = 'Nastaveno špatné schéma.';
@@ -302,7 +302,6 @@
 	$lang['strcachevalue'] = 'Cache hodnota';
 	$lang['strlogcount'] = 'Log Count';
 	$lang['striscycled'] = 'Je cyklická?';
-	$lang['striscalled'] = 'Je called?';
 	$lang['strsequenceneedsname'] = 'Musíš zadat název sekvence.';
 	$lang['strsequencereset'] = 'Reset sekvence.';
 	$lang['strsequenceresetbad'] = 'Reset sekvence se nepovedl.';
