@@ -4,7 +4,7 @@
 	 * English language file for phpPgAdmin.  Use this as a basis
 	 * for new translations.
 	 *
-	 * $Id: english.php,v 1.167.2.1 2005/04/13 08:33:01 chriskl Exp $
+	 * $Id: english.php,v 1.232 2008/02/23 16:34:33 ioguix Exp $
 	 */
 
 	// Language and character set
@@ -14,7 +14,7 @@
 	$lang['appdbencoding'] = 'LATIN1';
 	$lang['applangdir'] = 'ltr';
 
-	// Welcome  
+	// Welcome
 	$lang['strintro'] = 'Welcome to phpPgAdmin.';
 	$lang['strppahome'] = 'phpPgAdmin Homepage';
 	$lang['strpgsqlhome'] = 'PostgreSQL Homepage';
@@ -29,6 +29,10 @@
 	$lang['strloginfailed'] = 'Login failed';
 	$lang['strlogindisallowed'] = 'Login disallowed for security reasons.';
 	$lang['strserver'] = 'Server';
+	$lang['strservers'] = 'Servers';
+	$lang['strintroduction'] = 'Introduction';
+	$lang['strhost'] = 'Host';
+	$lang['strport'] = 'Port';
 	$lang['strlogout'] = 'Logout';
 	$lang['strowner'] = 'Owner';
 	$lang['straction'] = 'Action';
@@ -37,6 +41,8 @@
 	$lang['strdefinition'] = 'Definition';
 	$lang['strproperties'] = 'Properties';
 	$lang['strbrowse'] = 'Browse';
+	$lang['strenable'] = 'Enable';
+	$lang['strdisable'] = 'Disable';
 	$lang['strdrop'] = 'Drop';
 	$lang['strdropped'] = 'Dropped';
 	$lang['strnull'] = 'Null';
@@ -54,6 +60,7 @@
 	$lang['stralter'] = 'Alter';
 	$lang['strok'] = 'OK';
 	$lang['strcancel'] = 'Cancel';
+	$lang['strac'] = 'Enable AutoComplete';
 	$lang['strsave'] = 'Save';
 	$lang['strreset'] = 'Reset';
 	$lang['strinsert'] = 'Insert';
@@ -71,7 +78,6 @@
 	$lang['strrows'] = 'row(s)';
 	$lang['strrowsaff'] = 'row(s) affected.';
 	$lang['strobjects'] = 'object(s)';
-	$lang['strexample'] = 'eg.';
 	$lang['strback'] = 'Back';
 	$lang['strqueryresults'] = 'Query Results';
 	$lang['strshow'] = 'Show';
@@ -83,15 +89,17 @@
 	$lang['strprimary'] = 'Primary';
 	$lang['strexport'] = 'Export';
 	$lang['strimport'] = 'Import';
+	$lang['strallowednulls'] = 'Allowed NULL characters';
+	$lang['strbackslashn'] = '\N';
+	$lang['stremptystring'] = 'Empty string/field';
 	$lang['strsql'] = 'SQL';
-	$lang['strgo'] = 'Go';
 	$lang['stradmin'] = 'Admin';
 	$lang['strvacuum'] = 'Vacuum';
 	$lang['stranalyze'] = 'Analyze';
-	$lang['strcluster'] = 'Cluster';
+	$lang['strclusterindex'] = 'Cluster';
 	$lang['strclustered'] = 'Clustered?';
 	$lang['strreindex'] = 'Reindex';
-	$lang['strrun'] = 'Run';
+	$lang['strexecute'] = 'Execute';
 	$lang['stradd'] = 'Add';
 	$lang['strevent'] = 'Event';
 	$lang['strwhere'] = 'Where';
@@ -105,8 +113,6 @@
 	$lang['strseparator'] = ': ';
 	$lang['strexpand'] = 'Expand';
 	$lang['strcollapse'] = 'Collapse';
-	$lang['strexplain'] = 'Explain';
-	$lang['strexplainanalyze'] = 'Explain Analyze';
 	$lang['strfind'] = 'Find';
 	$lang['stroptions'] = 'Options';
 	$lang['strrefresh'] = 'Refresh';
@@ -126,12 +132,34 @@
 	$lang['strstarttime'] = 'Start Time';
 	$lang['strfile'] = 'File';
 	$lang['strfileimported'] = 'File imported.';
+	$lang['strtrycred'] = 'Use these credentials for all servers';
+	$lang['stractionsonmultiplelines'] = 'Actions on multiple lines';
+	$lang['strselectall'] = 'Select all';
+	$lang['strunselectall'] = 'Unselect all';
+	$lang['strlocale'] = 'Locale';
+
+	// User-supplied SQL history
+	$lang['strhistory'] = 'History';
+	$lang['strnohistory'] = 'No history.';
+	$lang['strclearhistory'] = 'Clear history';
+	$lang['strdelhistory'] = 'Delete from history';
+	$lang['strconfdelhistory'] = 'Really remove this request from history?';
+	$lang['strconfclearhistory'] = 'Really clear history?';
+	$lang['strnodatabaseselected'] = 'Please, select a database.';
+
+	// Database sizes
+	$lang['strsize'] = 'Size';
+	$lang['strbytes'] = 'bytes';
+	$lang['strkb'] = 'kB';
+	$lang['strmb'] = 'MB';
+	$lang['strgb'] = 'GB';
+	$lang['strtb'] = 'TB';
 
 	// Error handling
-	$lang['strnoframes'] = 'You need a frames-enabled browser to use this application.';
+	$lang['strnoframes'] = 'This application works best with a frames-enabled browser, but can be used without frames by following the link below.';
+	$lang['strnoframeslink'] = 'Use without frames';
 	$lang['strbadconfig'] = 'Your config.inc.php is out of date. You will need to regenerate it from the new config.inc.php-dist.';
 	$lang['strnotloaded'] = 'Your PHP installation does not support PostgreSQL. You need to recompile PHP using the --with-pgsql configure option.';
-	$lang['strphpversionnotsupported'] = 'Version of PHP not supported. Please upgrade to version %s or later.';
 	$lang['strpostgresqlversionnotsupported'] = 'Version of PostgreSQL not supported. Please upgrade to version %s or later.';
 	$lang['strbadschema'] = 'Invalid schema specified.';
 	$lang['strbadencoding'] = 'Failed to set client encoding in database.';
@@ -144,8 +172,13 @@
 	$lang['strnoreportsdb'] = 'You have not created the reports database. Read the INSTALL file for directions.';
 	$lang['strnouploads'] = 'File uploads are disabled.';
 	$lang['strimporterror'] = 'Import error.';
+	$lang['strimporterror-fileformat'] = 'Import error: Failed to automatically determine the file format.';
 	$lang['strimporterrorline'] = 'Import error on line %s.';
-	$lang['strcannotdumponwindows'] = 'Dumping of complex table and schema names on Windows is not supported.  Please see the FAQ.';
+	$lang['strimporterrorline-badcolumnnum'] = 'Import error on line %s: Line does not possess the correct number of columns.';
+	$lang['strimporterror-uploadedfile'] = 'Import error: File could not be uploaded to the server';
+	$lang['strcannotdumponwindows'] = 'Dumping of complex table and schema names on Windows is not supported.';
+	$lang['strinvalidserverparam'] = 'Attempt to connect with invalid server parameter, possibly someone is trying to hack your system.'; 
+	$lang['strnoserversupplied'] = 'No server supplied!';
 
 	// Tables
 	$lang['strtable'] = 'Table';
@@ -154,8 +187,14 @@
 	$lang['strnotables'] = 'No tables found.';
 	$lang['strnotable'] = 'No table found.';
 	$lang['strcreatetable'] = 'Create table';
+	$lang['strcreatetablelike'] = 'Create table like';
+	$lang['strcreatetablelikeparent'] = 'Source table';
+	$lang['strcreatelikewithdefaults'] = 'INCLUDE DEFAULTS';
+	$lang['strcreatelikewithconstraints'] = 'INCLUDE CONSTRAINTS';
+	$lang['strcreatelikewithindexes'] = 'INCLUDE INDEXES';
 	$lang['strtablename'] = 'Table name';
 	$lang['strtableneedsname'] = 'You must give a name for your table.';
+	$lang['strtablelikeneedslike'] = 'You must give a table to copy properties from.';
 	$lang['strtableneedsfield'] = 'You must specify at least one field.';
 	$lang['strtableneedscols'] = 'You must specify a valid number of columns.';
 	$lang['strtablecreated'] = 'Table created.';
@@ -169,6 +208,7 @@
 	$lang['strinsertrow'] = 'Insert row';
 	$lang['strrowinserted'] = 'Row inserted.';
 	$lang['strrowinsertedbad'] = 'Row insert failed.';
+	$lang['strrowduplicate'] = 'Row insert failed, attempted to do duplicate insert.';
 	$lang['streditrow'] = 'Edit row';
 	$lang['strrowupdated'] = 'Row updated.';
 	$lang['strrowupdatedbad'] = 'Row update failed.';
@@ -182,7 +222,6 @@
 	$lang['strselectallfields'] = 'Select all fields';
 	$lang['strselectneedscol'] = 'You must show at least one column.';
 	$lang['strselectunary'] = 'Unary operators cannot have values.';
-	$lang['straltercolumn'] = 'Alter column';
 	$lang['strcolumnaltered'] = 'Column altered.';
 	$lang['strcolumnalteredbad'] = 'Column alteration failed.';
 	$lang['strconfdropcolumn'] = 'Are you sure you want to drop column "%s" from table "%s"?';
@@ -200,8 +239,17 @@
 	$lang['strtabbed'] = 'Tabbed';
 	$lang['strauto'] = 'Auto';
 	$lang['strconfvacuumtable'] = 'Are you sure you want to vacuum "%s"?';
-	$lang['strestimatedrowcount'] = 'Estimated Row Count';
+	$lang['strconfanalyzetable'] = 'Are you sure you want to analyze "%s"?';
+	$lang['strestimatedrowcount'] = 'Estimated row count';
+	$lang['strspecifytabletoanalyze'] = 'You must specify at least one table to analyze.';
+	$lang['strspecifytabletoempty'] = 'You must specify at least one table to empty.';
+	$lang['strspecifytabletodrop'] = 'You must specify at least one table to drop.';
+	$lang['strspecifytabletovacuum'] = 'You must specify at least one table to vacuum.';
 
+	// Columns
+	$lang['strcolprop'] = 'Column properties';
+	$lang['strnotableprovided'] = 'No table provided!';
+		
 	// Users
 	$lang['struser'] = 'User';
 	$lang['strusers'] = 'Users';
@@ -232,10 +280,10 @@
 	// Groups
 	$lang['strgroup'] = 'Group';
 	$lang['strgroups'] = 'Groups';
+	$lang['strshowallgroups'] = 'Show all groups';
 	$lang['strnogroup'] = 'Group not found.';
 	$lang['strnogroups'] = 'No groups found.';
 	$lang['strcreategroup'] = 'Create group';
-	$lang['strshowallgroups'] = 'Show all groups';
 	$lang['strgroupneedsname'] = 'You must give a name for your group.';
 	$lang['strgroupcreated'] = 'Group created.';
 	$lang['strgroupcreatedbad'] = 'Group creation failed.';	
@@ -243,6 +291,8 @@
 	$lang['strgroupdropped'] = 'Group dropped.';
 	$lang['strgroupdroppedbad'] = 'Group drop failed.';
 	$lang['strmembers'] = 'Members';
+	$lang['strmemberof'] = 'Member of';
+	$lang['stradminmembers'] = 'Admin members';
 	$lang['straddmember'] = 'Add member';
 	$lang['strmemberadded'] = 'Member added.';
 	$lang['strmemberaddedbad'] = 'Member add failed.';
@@ -251,6 +301,28 @@
 	$lang['strmemberdropped'] = 'Member dropped.';
 	$lang['strmemberdroppedbad'] = 'Member drop failed.';
 
+	// Roles
+	$lang['strrole'] = 'Role';
+	$lang['strroles'] = 'Roles';
+	$lang['strshowallroles'] = 'Show all roles';
+	$lang['strnoroles'] = 'No roles found.';
+	$lang['strinheritsprivs'] = 'Inherits privileges?';
+	$lang['strcreaterole'] = 'Create role';
+	$lang['strcancreaterole'] = 'Can create role?';
+	$lang['strrolecreated'] = 'Role created.';
+	$lang['strrolecreatedbad'] = 'Create role failed.';
+	$lang['strrolealtered'] = 'Role altered.';
+	$lang['strrolealteredbad'] = 'Role alter failed.';
+	$lang['strcanlogin'] = 'Can login?';
+	$lang['strconnlimit'] = 'Connection limit';
+	$lang['strdroprole'] = 'Drop role';
+	$lang['strconfdroprole'] = 'Are you sure you want to drop the role "%s"?';
+	$lang['strroledropped'] = 'Role dropped.';
+	$lang['strroledroppedbad'] = 'Role drop failed.';
+	$lang['strnolimit'] = 'No limit';
+	$lang['strnever'] = 'Never';
+	$lang['strroleneedsname'] = 'You must give a name for the role.';
+
 	// Privileges
 	$lang['strprivilege'] = 'Privilege';
 	$lang['strprivileges'] = 'Privileges';
@@ -267,7 +339,6 @@
 	$lang['strdatabase'] = 'Database';
 	$lang['strdatabases'] = 'Databases';
 	$lang['strshowalldatabases'] = 'Show all databases';
-	$lang['strnodatabase'] = 'No database found.';
 	$lang['strnodatabases'] = 'No databases found.';
 	$lang['strcreatedatabase'] = 'Create database';
 	$lang['strdatabasename'] = 'Database name';
@@ -291,6 +362,9 @@
 	$lang['strsignalsent'] = 'Signal sent.';
 	$lang['strsignalsentbad'] = 'Sending signal failed.';
 	$lang['strallobjects'] = 'All objects';
+	$lang['strdatabasealtered'] = 'Database altered.';
+	$lang['strdatabasealteredbad'] = 'Database alter failed.';
+	$lang['strspecifydatabasetodrop'] = 'You must specify at least one database to drop.';
 
 	// Views
 	$lang['strview'] = 'View';
@@ -310,9 +384,15 @@
 	$lang['strviewdroppedbad'] = 'View drop failed.';
 	$lang['strviewupdated'] = 'View updated.';
 	$lang['strviewupdatedbad'] = 'View update failed.';
-	$lang['strviewlink'] = 'Linking Keys';
-	$lang['strviewconditions'] = 'Additional Conditions';
+	$lang['strviewlink'] = 'Linking keys';
+	$lang['strviewconditions'] = 'Additional conditions';
 	$lang['strcreateviewwiz'] = 'Create view with wizard';
+	$lang['strrenamedupfields'] = 'Rename duplicate fields';
+	$lang['strdropdupfields'] = 'Drop duplicate fields';
+	$lang['strerrordupfields'] = 'Error on duplicate fields';
+	$lang['strviewaltered'] = 'View altered.';
+	$lang['strviewalteredbad'] = 'View alteration failed.';
+	$lang['strspecifyviewtodrop'] = 'You must specify at least one view to drop.';
 
 	// Sequences
 	$lang['strsequence'] = 'Sequence';
@@ -328,21 +408,30 @@
 	$lang['strminvalue'] = 'Min value';
 	$lang['strcachevalue'] = 'Cache value';
 	$lang['strlogcount'] = 'Log count';
-	$lang['striscycled'] = 'Is cycled?';
-	$lang['striscalled'] = 'Is called?';
+	$lang['strcancycle'] = 'Can cycle?';
+	$lang['striscalled'] = 'Will increment last value before returning next value (is_called)?';
 	$lang['strsequenceneedsname'] = 'You must specify a name for your sequence.';
 	$lang['strsequencecreated'] = 'Sequence created.';
-	$lang['strsequencecreatedbad'] = 'Sequence creation failed.'; 
+	$lang['strsequencecreatedbad'] = 'Sequence creation failed.';
 	$lang['strconfdropsequence'] = 'Are you sure you want to drop sequence "%s"?';
 	$lang['strsequencedropped'] = 'Sequence dropped.';
 	$lang['strsequencedroppedbad'] = 'Sequence drop failed.';
 	$lang['strsequencereset'] = 'Sequence reset.';
-	$lang['strsequenceresetbad'] = 'Sequence reset failed.'; 
-
+	$lang['strsequenceresetbad'] = 'Sequence reset failed.';
+ 	$lang['strsequencealtered'] = 'Sequence altered.';
+ 	$lang['strsequencealteredbad'] = 'Sequence alteration failed.';
+ 	$lang['strsetval'] = 'Set value';
+ 	$lang['strsequencesetval'] = 'Sequence value set.';
+ 	$lang['strsequencesetvalbad'] = 'Sequence value set failed.';
+ 	$lang['strnextval'] = 'Increment value';
+ 	$lang['strsequencenextval'] = 'Sequence incremented.';
+ 	$lang['strsequencenextvalbad'] = 'Sequence increment failed.';
+	$lang['strspecifysequencetodrop'] = 'You must specify at least one sequence to drop.';
+	
 	// Indexes
 	$lang['strindex'] = 'Index';
 	$lang['strindexes'] = 'Indexes';
-	$lang['strindexname'] = 'Index Name';
+	$lang['strindexname'] = 'Index name';
 	$lang['strshowallindexes'] = 'Show all indexes';
 	$lang['strnoindex'] = 'No index found.';
 	$lang['strnoindexes'] = 'No indexes found.';
@@ -351,7 +440,7 @@
 	$lang['strcolumnname'] = 'Column name';
 	$lang['strindexneedsname'] = 'You must give a name for your index.';
 	$lang['strindexneedscols'] = 'Indexes require a valid number of columns.';
-	$lang['strindexcreated'] = 'Index created';
+	$lang['strindexcreated'] = 'Index created.';
 	$lang['strindexcreatedbad'] = 'Index creation failed.';
 	$lang['strconfdropindex'] = 'Are you sure you want to drop the index "%s"?';
 	$lang['strindexdropped'] = 'Index dropped.';
@@ -382,6 +471,7 @@
 	$lang['strruledroppedbad'] = 'Rule drop failed.';
 
 	// Constraints
+	$lang['strconstraint'] = 'Constraint';
 	$lang['strconstraints'] = 'Constraints';
 	$lang['strshowallconstraints'] = 'Show all constraints';
 	$lang['strnoconstraints'] = 'No constraints found.';
@@ -424,7 +514,6 @@
 	$lang['strcreatecfunction'] = 'Create C function';
 	$lang['strfunctionname'] = 'Function name';
 	$lang['strreturns'] = 'Returns';
-	$lang['strarguments'] = 'Arguments';
 	$lang['strproglanguage'] = 'Programming language';
 	$lang['strfunctionneedsname'] = 'You must give a name for your function.';
 	$lang['strfunctionneedsdef'] = 'You must give a definition for your function.';
@@ -437,6 +526,22 @@
 	$lang['strfunctionupdatedbad'] = 'Function update failed.';
 	$lang['strobjectfile'] = 'Object File';
 	$lang['strlinksymbol'] = 'Link Symbol';
+	$lang['strarguments'] = 'Arguments';
+	$lang['strargmode'] = 'Mode';
+	$lang['strargtype'] = 'Type';
+	$lang['strargadd'] = 'Add another argument';
+	$lang['strargremove'] = 'Remove this argument';
+	$lang['strargnoargs'] = 'This function will not take any arguments.';
+	$lang['strargenableargs'] = 'Enable arguments being passed to this function.';
+	$lang['strargnorowabove'] = 'There needs to be a row above this row.';
+	$lang['strargnorowbelow'] = 'There needs to be a row below this row.';
+	$lang['strargraise'] = 'Move up.';
+	$lang['strarglower'] = 'Move down.';
+	$lang['strargremoveconfirm'] = 'Are you sure you want to remove this argument? This CANNOT be undone.';
+	$lang['strfunctioncosting'] = 'Function Costing';
+	$lang['strresultrows'] = 'Result Rows';
+	$lang['strexecutioncost'] = 'Execution Cost';
+	$lang['strspecifyfunctiontodrop'] = 'You must specify at least one function to drop.';
 
 	// Triggers
 	$lang['strtrigger'] = 'Trigger';
@@ -450,10 +555,17 @@
 	$lang['strtriggercreated'] = 'Trigger created.';
 	$lang['strtriggercreatedbad'] = 'Trigger creation failed.';
 	$lang['strconfdroptrigger'] = 'Are you sure you want to drop the trigger "%s" on "%s"?';
+	$lang['strconfenabletrigger'] = 'Are you sure you want to enable the trigger "%s" on "%s"?';
+	$lang['strconfdisabletrigger'] = 'Are you sure you want to disable the trigger "%s" on "%s"?';
 	$lang['strtriggerdropped'] = 'Trigger dropped.';
 	$lang['strtriggerdroppedbad'] = 'Trigger drop failed.';
+	$lang['strtriggerenabled'] = 'Trigger enabled.';
+	$lang['strtriggerenabledbad'] = 'Trigger enable failed.';
+	$lang['strtriggerdisabled'] = 'Trigger disabled.';
+	$lang['strtriggerdisabledbad'] = 'Trigger disable failed.';
 	$lang['strtriggeraltered'] = 'Trigger altered.';
 	$lang['strtriggeralteredbad'] = 'Trigger alteration failed.';
+	$lang['strforeach'] = 'For each';
 
 	// Types
 	$lang['strtype'] = 'Type';
@@ -463,9 +575,11 @@
 	$lang['strnotypes'] = 'No types found.';
 	$lang['strcreatetype'] = 'Create type';
 	$lang['strcreatecomptype'] = 'Create composite type';
+	$lang['strcreateenumtype'] = 'Create enum type';
 	$lang['strtypeneedsfield'] = 'You must specify at least one field.';
-	$lang['strtypeneedscols'] = 'You must specify a valid number of fields.';	
-	$lang['strtypename'] = 'Type name';
+	$lang['strtypeneedsvalue'] = 'You must specify at least one value.';
+	$lang['strtypeneedscols'] = 'You must specify a valid number of fields.';
+	$lang['strtypeneedsvals'] = 'You must specify a valid number of values.';
 	$lang['strinputfn'] = 'Input function';
 	$lang['stroutputfn'] = 'Output function';
 	$lang['strpassbyval'] = 'Passed by val?';
@@ -475,9 +589,10 @@
 	$lang['strstorage'] = 'Storage';
 	$lang['strfield'] = 'Field';
 	$lang['strnumfields'] = 'Num. of fields';
+	$lang['strnumvalues'] = 'Num. of values';
 	$lang['strtypeneedsname'] = 'You must give a name for your type.';
 	$lang['strtypeneedslen'] = 'You must give a length for your type.';
-	$lang['strtypecreated'] = 'Type created';
+	$lang['strtypecreated'] = 'Type created.';
 	$lang['strtypecreatedbad'] = 'Type creation failed.';
 	$lang['strconfdroptype'] = 'Are you sure you want to drop the type "%s"?';
 	$lang['strtypedropped'] = 'Type dropped.';
@@ -486,6 +601,8 @@
 	$lang['strbasetype'] = 'Base';
 	$lang['strcompositetype'] = 'Composite';
 	$lang['strpseudotype'] = 'Pseudo';
+	$lang['strenum'] = 'Enum';
+	$lang['strenumvalues'] = 'Enum values';
 
 	// Schemas
 	$lang['strschema'] = 'Schema';
@@ -496,7 +613,7 @@
 	$lang['strcreateschema'] = 'Create schema';
 	$lang['strschemaname'] = 'Schema name';
 	$lang['strschemaneedsname'] = 'You must give a name for your schema.';
-	$lang['strschemacreated'] = 'Schema created';
+	$lang['strschemacreated'] = 'Schema created.';
 	$lang['strschemacreatedbad'] = 'Schema creation failed.';
 	$lang['strconfdropschema'] = 'Are you sure you want to drop the schema "%s"?';
 	$lang['strschemadropped'] = 'Schema dropped.';
@@ -504,6 +621,7 @@
 	$lang['strschemaaltered'] = 'Schema altered.';
 	$lang['strschemaalteredbad'] = 'Schema alteration failed.';
 	$lang['strsearchpath'] = 'Schema search path';
+	$lang['strspecifyschematodrop'] = 'You must specify at least one schema to drop.';
 
 	// Reports
 	$lang['strreport'] = 'Report';
@@ -554,7 +672,7 @@
 	$lang['strlessthan'] = 'Less than';
 	$lang['strgreaterthan'] = 'Greater than';
 	$lang['stroperatorneedsname'] = 'You must give a name for your operator.';
-	$lang['stroperatorcreated'] = 'Operator created';
+	$lang['stroperatorcreated'] = 'Operator created.';
 	$lang['stroperatorcreatedbad'] = 'Operator creation failed.';
 	$lang['strconfdropoperator'] = 'Are you sure you want to drop the operator "%s"?';
 	$lang['stroperatordropped'] = 'Operator dropped.';
@@ -585,11 +703,31 @@
 	$lang['strreferringtables'] = 'Referring tables';
 	$lang['strparenttables'] = 'Parent tables';
 	$lang['strchildtables'] = 'Child tables';
-	
+
 	// Aggregates
+	$lang['straggregate'] = 'Aggregate';
 	$lang['straggregates'] = 'Aggregates';
 	$lang['strnoaggregates'] = 'No aggregates found.';
 	$lang['stralltypes'] = '(All types)';
+	$lang['strcreateaggregate'] = 'Create aggregate';
+	$lang['straggrbasetype'] = 'Input data type';
+	$lang['straggrsfunc'] = 'State transition function';
+	$lang['straggrstype'] = 'Data type for state value';
+	$lang['straggrffunc'] = 'Final function';
+	$lang['straggrinitcond'] = 'Initial condition';
+	$lang['straggrsortop'] = 'Sort operator';
+	$lang['strconfdropaggregate'] = 'Are you sure you want to drop the aggregate "%s"?';
+	$lang['straggregatedropped'] = 'Aggregate dropped.';
+	$lang['straggregatedroppedbad'] = 'Aggregate drop failed.';
+	$lang['straggraltered'] = 'Aggregate altered.';
+	$lang['straggralteredbad'] = 'Aggregate alteration failed.';
+	$lang['straggrneedsname'] = 'You must specify a name for the aggregate.';
+	$lang['straggrneedsbasetype'] = 'You must specify the input data type for the aggregate.';
+	$lang['straggrneedssfunc'] = 'You must specify the name of the state transition function for the aggregate.';
+	$lang['straggrneedsstype'] = 'You must specify the data type for the aggregate\'s state value.';
+	$lang['straggrcreated'] = 'Aggregate created.';
+	$lang['straggrcreatedbad'] = 'Aggregate creation failed.';
+	$lang['straggrshowall'] = 'Show all aggregates';
 
 	// Operator Classes
 	$lang['stropclasses'] = 'Op Classes';
@@ -630,10 +768,208 @@
 	$lang['strtablespacealtered'] = 'Tablespace altered.';
 	$lang['strtablespacealteredbad'] = 'Tablespace alteration failed.';
 
+	// Slony clusters
+	$lang['strcluster'] = 'Cluster';
+	$lang['strnoclusters'] = 'No clusters found.';
+	$lang['strconfdropcluster'] = 'Are you sure you want to drop cluster "%s"?';
+	$lang['strclusterdropped'] = 'Cluster dropped.';
+	$lang['strclusterdroppedbad'] = 'Cluster drop failed.';
+	$lang['strinitcluster'] = 'Initialize cluster';
+	$lang['strclustercreated'] = 'Cluster initialized.';
+	$lang['strclustercreatedbad'] = 'Cluster initialization failed.';
+	$lang['strclusterneedsname'] = 'You must give a name for the cluster.';
+	$lang['strclusterneedsnodeid'] = 'You must give an ID for the local node.';
+
+	// Slony nodes
+	$lang['strnodes'] = 'Nodes';
+	$lang['strnonodes'] = 'No nodes found.';
+	$lang['strcreatenode'] = 'Create node';
+	$lang['strid'] = 'ID';
+	$lang['stractive'] = 'Active';
+	$lang['strnodecreated'] = 'Node created.';
+	$lang['strnodecreatedbad'] = 'Node creation failed.';
+	$lang['strconfdropnode'] = 'Are you sure you want to drop node "%s"?';
+	$lang['strnodedropped'] = 'Node dropped.';
+	$lang['strnodedroppedbad'] = 'Node drop failed.';
+	$lang['strfailover'] = 'Failover';
+	$lang['strnodefailedover'] = 'Node failed over.';
+	$lang['strnodefailedoverbad'] = 'Node failover failed.';
+	$lang['strstatus'] = 'Status';	
+	$lang['strhealthy'] = 'Healthy';
+	$lang['stroutofsync'] = 'Out of sync';
+	$lang['strunknown'] = 'Unknown';	
+
+	// Slony paths	
+	$lang['strpaths'] = 'Paths';
+	$lang['strnopaths'] = 'No paths found.';
+	$lang['strcreatepath'] = 'Create path';
+	$lang['strnodename'] = 'Node name';
+	$lang['strnodeid'] = 'Node ID';
+	$lang['strconninfo'] = 'Connection string';
+	$lang['strconnretry'] = 'Seconds before retry to connect';
+	$lang['strpathneedsconninfo'] = 'You must give a connection string for the path.';
+	$lang['strpathneedsconnretry'] = 'You must give the number of seconds to wait before retry to connect.';
+	$lang['strpathcreated'] = 'Path created.';
+	$lang['strpathcreatedbad'] = 'Path creation failed.';
+	$lang['strconfdroppath'] = 'Are you sure you want to drop path "%s"?';
+	$lang['strpathdropped'] = 'Path dropped.';
+	$lang['strpathdroppedbad'] = 'Path drop failed.';
+
+	// Slony listens
+	$lang['strlistens'] = 'Listens';
+	$lang['strnolistens'] = 'No listens found.';
+	$lang['strcreatelisten'] = 'Create listen';
+	$lang['strlistencreated'] = 'Listen created.';
+	$lang['strlistencreatedbad'] = 'Listen creation failed.';
+	$lang['strconfdroplisten'] = 'Are you sure you want to drop listen "%s"?';
+	$lang['strlistendropped'] = 'Listen dropped.';
+	$lang['strlistendroppedbad'] = 'Listen drop failed.';
+
+	// Slony replication sets
+	$lang['strrepsets'] = 'Replication sets';
+	$lang['strnorepsets'] = 'No replication sets found.';
+	$lang['strcreaterepset'] = 'Create replication set';
+	$lang['strrepsetcreated'] = 'Replication set created.';
+	$lang['strrepsetcreatedbad'] = 'Replication set creation failed.';
+	$lang['strconfdroprepset'] = 'Are you sure you want to drop replication set "%s"?';
+	$lang['strrepsetdropped'] = 'Replication set dropped.';
+	$lang['strrepsetdroppedbad'] = 'Replication set drop failed.';
+	$lang['strmerge'] = 'Merge';
+	$lang['strmergeinto'] = 'Merge into';
+	$lang['strrepsetmerged'] = 'Replication sets merged.';
+	$lang['strrepsetmergedbad'] = 'Replication sets merge failed.';
+	$lang['strmove'] = 'Move';
+	$lang['strneworigin'] = 'New origin';
+	$lang['strrepsetmoved'] = 'Replication set moved.';
+	$lang['strrepsetmovedbad'] = 'Replication set move failed.';
+	$lang['strnewrepset'] = 'New replication set';
+	$lang['strlock'] = 'Lock';
+	$lang['strlocked'] = 'Locked';
+	$lang['strunlock'] = 'Unlock';
+	$lang['strconflockrepset'] = 'Are you sure you want to lock replication set "%s"?';
+	$lang['strrepsetlocked'] = 'Replication set locked.';
+	$lang['strrepsetlockedbad'] = 'Replication set lock failed.';
+	$lang['strconfunlockrepset'] = 'Are you sure you want to unlock replication set "%s"?';
+	$lang['strrepsetunlocked'] = 'Replication set unlocked.';
+	$lang['strrepsetunlockedbad'] = 'Replication set unlock failed.';
+	$lang['stronlyonnode'] = 'Only on node';
+	$lang['strddlscript'] = 'DDL script';
+	$lang['strscriptneedsbody'] = 'You must supply a script to be executed on all nodes.';
+	$lang['strscriptexecuted'] = 'Replication set DDL script executed.';
+	$lang['strscriptexecutedbad'] = 'Failed executing replication set DDL script.';
+	$lang['strtabletriggerstoretain'] = 'The following triggers will NOT be disabled by Slony:';
+
+	// Slony tables in replication sets
+	$lang['straddtable'] = 'Add table';
+	$lang['strtableneedsuniquekey'] = 'Table to be added requires a primary or unique key.';
+	$lang['strtableaddedtorepset'] = 'Table added to replication set.';
+	$lang['strtableaddedtorepsetbad'] = 'Failed adding table to replication set.';
+	$lang['strconfremovetablefromrepset'] = 'Are you sure you want to drop the table "%s" from replication set "%s"?';
+	$lang['strtableremovedfromrepset'] = 'Table dropped from replication set.';
+	$lang['strtableremovedfromrepsetbad'] = 'Failed to drop table from replication set.';
+
+	// Slony sequences in replication sets
+	$lang['straddsequence'] = 'Add sequence';
+	$lang['strsequenceaddedtorepset'] = 'Sequence added to replication set.';
+	$lang['strsequenceaddedtorepsetbad'] = 'Failed adding sequence to replication set.';
+	$lang['strconfremovesequencefromrepset'] = 'Are you sure you want to drop the sequence "%s" from replication set "%s"?';
+	$lang['strsequenceremovedfromrepset'] = 'Sequence dropped from replication set.';
+	$lang['strsequenceremovedfromrepsetbad'] = 'Failed to drop sequence from replication set.';
+
+	// Slony subscriptions
+	$lang['strsubscriptions'] = 'Subscriptions';
+	$lang['strnosubscriptions'] = 'No subscriptions found.';
+
 	// Miscellaneous
 	$lang['strtopbar'] = '%s running on %s:%s -- You are logged in as user "%s", %s';
 	$lang['strtimefmt'] = 'jS M, Y g:iA';
 	$lang['strhelp'] = 'Help';
 	$lang['strhelpicon'] = '?';
+	$lang['strhelppagebrowser'] = 'Help page browser';
+	$lang['strselecthelppage'] = 'Select a help page';
+	$lang['strinvalidhelppage'] = 'Invalid help page.';
+	$lang['strlogintitle'] = 'Login to %s';
+	$lang['strlogoutmsg'] = 'Logged out of %s';
+	$lang['strloading'] = 'Loading...';
+	$lang['strerrorloading'] = 'Error Loading';
+	$lang['strclicktoreload'] = 'Click to reload';
 
+	// Autovacuum
+	$lang['strautovacuum'] = 'Autovacuum';
+	$lang['strturnedon'] = 'Turned On';
+	$lang['strturnedoff'] = 'Turned Off';
+	$lang['strenabled'] = 'Enabled';
+	$lang['strvacuumbasethreshold'] = 'Vacuum Base Threshold';
+	$lang['strvacuumscalefactor'] = 'Vacuum Scale Factor';
+	$lang['stranalybasethreshold'] = 'Analyze Base Threshold';
+	$lang['stranalyzescalefactor'] = 'Analyze Scale Factor';
+	$lang['strvacuumcostdelay'] = 'Vacuum Cost Delay';
+	$lang['strvacuumcostlimit'] = 'Vacuum Cost Limit';
+
+	// Table-level Locks
+	$lang['strlocks'] = 'Locks';
+	$lang['strtransaction'] = 'Transaction ID';
+	$lang['strvirtualtransaction'] = 'Virtual Transaction ID';
+	$lang['strprocessid'] = 'Process ID';
+	$lang['strmode'] = 'Lock mode';
+	$lang['strislockheld'] = 'Is lock held?';
+
+	// Prepared transactions
+	$lang['strpreparedxacts'] = 'Prepared transactions';
+	$lang['strxactid'] = 'Transaction ID';
+	$lang['strgid'] = 'Global ID';
+	
+	// Fulltext search
+	$lang['strfulltext'] = 'Full Text Search';
+	$lang['strftsconfig'] = 'FTS configuration';
+	$lang['strftsconfigs'] = 'Configurations';
+	$lang['strftscreateconfig'] = 'Create FTS configuration';
+	$lang['strftscreatedict'] = 'Create dictionary';
+	$lang['strftscreatedicttemplate'] = 'Create dictionary template';
+	$lang['strftscreateparser'] = 'Create parser';
+	$lang['strftsnoconfigs'] = 'No FTS configuration found.';
+	$lang['strftsconfigdropped'] = 'FTS configuration dropped.';
+	$lang['strftsconfigdroppedbad'] = 'FTS configuration drop failed.';
+	$lang['strconfdropftsconfig'] = 'Are you sure you want to drop the FTS configuration "%s"?';
+	$lang['strconfdropftsdict'] = 'Are you sure you want to drop the FTS dictionary "%s"?';
+	$lang['strconfdropftsmapping'] = 'Are you sure you want to drop mapping "%s" of FTS configuration "%s"?';
+	$lang['strftstemplate'] = 'Template';
+	$lang['strftsparser'] = 'Parser';
+	$lang['strftsconfigneedsname'] = 'You must give a name for your FTS configuration.';
+	$lang['strftsconfigcreated'] = 'FTS configuration created.';
+	$lang['strftsconfigcreatedbad'] = 'FTS configuration creation failed.';
+	$lang['strftsmapping'] = 'Mapping';
+	$lang['strftsdicts'] = 'Dictionaries';
+	$lang['strftsdict'] = 'Dictionary';
+	$lang['strftsemptymap'] = 'Empty FTS configuration map.';
+	$lang['strftsconfigaltered'] = 'FTS configuration altered.';
+	$lang['strftsconfigalteredbad'] = 'FTS configuration alter failed.';
+	$lang['strftsconfigmap'] = 'FTS configuration map';
+	$lang['strftsparsers'] = 'FTS parsers';
+	$lang['strftsnoparsers'] = 'No FTS parsers available.';
+	$lang['strftsnodicts'] = 'No FTS dictionaries available.';
+	$lang['strftsdictcreated'] = 'FTS dictionary created.';
+	$lang['strftsdictcreatedbad'] = 'FTS dictionary creation failed.';
+	$lang['strftslexize'] = 'Lexize';
+	$lang['strftsinit'] = 'Init';
+	$lang['strftsoptionsvalues'] = 'Options and values';
+	$lang['strftsdictneedsname'] = 'You must give a name for your FTS dictionary.';
+	$lang['strftsdictdropped'] = 'FTS dictionary dropped.';
+	$lang['strftsdictdroppedbad'] = 'FTS dictionary drop failed.';
+	$lang['strftsdictaltered'] = 'FTS dictionary altered.';
+	$lang['strftsdictalteredbad'] = 'FTS dictionary alter failed.';
+	$lang['strftsaddmapping'] = 'Add new mapping';
+	$lang['strftsspecifymappingtodrop'] = 'You must specify at least one mapping to drop.';
+	$lang['strftsspecifyconfigtoalter'] = 'You must specify a FTS configuration to alter';
+	$lang['strftsmappingdropped'] = 'FTS mapping dropped.';
+	$lang['strftsmappingdroppedbad'] = 'FTS mapping drop failed.';
+	$lang['strftsnodictionaries'] = 'No dictionaries found.';
+	$lang['strftsmappingaltered'] = 'FTS mapping altered.';
+	$lang['strftsmappingalteredbad'] = 'FTS mapping alter failed.';
+	$lang['strftsmappingadded'] = 'FTS mapping added.';
+	$lang['strftsmappingaddedbad'] = 'FTS mapping add failed.';
+	$lang['strftstabconfigs'] = 'Configurations';
+	$lang['strftstabdicts'] = 'Dictionaries';
+	$lang['strftstabparsers'] = 'Parsers';
+	$lang['strftscantparsercopy'] = 'Can\'t specify both parser and template during text search configuration creation.';
 ?>
